summaryrefslogtreecommitdiff
path: root/src/linux/up-device-wup.c
diff options
context:
space:
mode:
authorRichard Hughes <richard@hughsie.com>2010-01-18 13:20:36 +0000
committerRichard Hughes <richard@hughsie.com>2010-01-18 13:20:36 +0000
commitbc928f7ae8b88d05ed648b62176c0ba25c8e5770 (patch)
tree48516d8209dee37818804bbbff8989902c8c0d94 /src/linux/up-device-wup.c
parentc8cec18f064f5cb86896e6ff17d96d73fb9fd0dc (diff)
trivial: switch to using the new udev attribute names (no ABI or API break)
Diffstat (limited to 'src/linux/up-device-wup.c')
-rw-r--r--src/linux/up-device-wup.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/linux/up-device-wup.c b/src/linux/up-device-wup.c
index ff89178..717e55d 100644
--- a/src/linux/up-device-wup.c
+++ b/src/linux/up-device-wup.c
@@ -306,7 +306,7 @@ up_device_wup_coldplug (UpDevice *device)
/* detect what kind of device we are */
native = G_UDEV_DEVICE (up_device_get_native (device));
- type = g_udev_device_get_property (native, "DKP_MONITOR_TYPE");
+ type = g_udev_device_get_property (native, "UP_MONITOR_TYPE");
if (type == NULL || g_strcmp0 (type, "wup") != 0)
goto out;
@@ -352,11 +352,11 @@ up_device_wup_coldplug (UpDevice *device)
up_device_wup_parse_command (wup, data);
g_free (data);
- /* prefer DKP names */
- vendor = g_udev_device_get_property (native, "DKP_VENDOR");
+ /* prefer UPOWER names */
+ vendor = g_udev_device_get_property (native, "UPOWER_VENDOR");
if (vendor == NULL)
vendor = g_udev_device_get_property (native, "ID_VENDOR");
- product = g_udev_device_get_property (native, "DKP_PRODUCT");
+ product = g_udev_device_get_property (native, "UPOWER_PRODUCT");
if (product == NULL)
product = g_udev_device_get_property (native, "ID_PRODUCT");